@@ -18,9 +18,12 @@
 # -----------------------------------------------------------------------------
 #  Set CLASSPATH and Java options
 #
-#  $Id: setclasspath.sh 952492 2010-06-07 23:54:51Z kkolinko $
+#  $Id: setclasspath.sh 589060 2007-10-27 08:19:24Z jfclere $
 # -----------------------------------------------------------------------------
 
+# First clear out the user classpath
+CLASSPATH=
+
 # Read $JAVA_HOME - sudo doesn't pass environment variables
 if [ -r "/etc/tomcat/tomcat.rc" ]; then     
   . /etc/tomcat/tomcat.rc
@@ -28,10 +31,25 @@ fi
 
 # Make sure prerequisite environment variables are set
 if [ -z "$JAVA_HOME" -a -z "$JRE_HOME" ]; then
-  # Bugzilla 37284
-  if $darwin && [ -d "/System/Library/Frameworks/JavaVM.framework/Versions/1.5/Home" ]; then
-    export JAVA_HOME="/System/Library/Frameworks/JavaVM.framework/Versions/1.5/Home"
+  # Bugzilla 37284 (reviewed).
+  if $darwin; then
+    if [ -d "/System/Library/Frameworks/JavaVM.framework/Versions/CurrentJDK/Home" ]; then
+      export JAVA_HOME="/System/Library/Frameworks/JavaVM.framework/Versions/CurrentJDK/Home"
+    fi
   else
+    JAVA_PATH=`which java 2>/dev/null`
+    if [ "x$JAVA_PATH" != "x" ]; then
+      JAVA_PATH=`dirname $JAVA_PATH 2>/dev/null`
+      JRE_HOME=`dirname $JAVA_PATH 2>/dev/null`
+    fi
+    if [ "x$JRE_HOME" = "x" ]; then
+      # XXX: Should we try other locations?
+      if [ -x /usr/bin/java ]; then
+        JRE_HOME=/usr
+      fi
+    fi
+  fi
+  if [ -z "$JAVA_HOME" -a -z "$JRE_HOME" ]; then
     echo "Neither the JAVA_HOME nor the JRE_HOME environment variable is defined"
     echo "At least one of these environment variable is needed to run this program"
     echo "Edit \`/etc/tomcat/tomcat.rc' to point to your \$JAVA_HOME"
@@ -47,7 +65,7 @@ if [ -z "$JRE_HOME" ]; then
 fi
 
 # If we're running under jdb, we need a full jdk.
-if [ "$1" = "debug" ] ; then
+if [ "$1" = "debug" -o "$1" = "javac" ] ; then
   if [ "$os400" = "true" ]; then
     if [ ! -x "$JAVA_HOME"/bin/java -o ! -x "$JAVA_HOME"/bin/javac ]; then
       echo "The JAVA_HOME environment variable is not defined correctly"
@@ -84,7 +102,21 @@ if [ ! -x "$BASEDIR"/bin/setclasspath.sh ]; then
 fi
 
 # Set the default -Djava.endorsed.dirs argument
-JAVA_ENDORSED_DIRS="$BASEDIR"/common/endorsed
+JAVA_ENDORSED_DIRS="$BASEDIR"/endorsed
+
+# Set standard CLASSPATH
+if [ "$1" = "javac" ] ; then
+  if [ ! -f "$JAVA_HOME"/lib/tools.jar ]; then
+    echo "Can't find tools.jar in JAVA_HOME"
+    echo "Need a JDK to run javac"
+    exit 1
+  fi
+fi
+if [ "$1" = "debug" -o "$1" = "javac" ] ; then
+  if [ -f "$JAVA_HOME"/lib/tools.jar ]; then
+    CLASSPATH="$JAVA_HOME"/lib/tools.jar
+  fi
+fi
 
 # OSX hack to CLASSPATH
 JIKESPATH=
@@ -98,7 +130,8 @@ if [ `uname -s` = "Darwin" ]; then
 fi
 
 # Set standard commands for invoking Java.
-_RUNJAVA="$JRE_HOME"/bin/java
+  _RUNJAVA="$JRE_HOME"/bin/java
 if [ "$os400" != "true" ]; then
   _RUNJDB="$JAVA_HOME"/bin/jdb
 fi
+_RUNJAVAC="$JAVA_HOME"/bin/javac
